# -----------------------------------------------------------------------------
#   Copyright (c) 2012 Bryce Johnson
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
# -----------------------------------------------------------------------------
class jira::install {

  group { $jira::group:
    ensure => present,
    gid    => $jira::gid
  } ->
  user { $jira::user:
    comment          => 'Jira daemon account',
    shell            => '/bin/true',
    home             => $jira::homedir,
    password         => '*',
    password_min_age => '0',
    password_max_age => '99999',
    managehome       => true,
    uid              => $jira::uid,
    gid              => $jira::gid,

  }

  if ! defined(File[$jira::installdir]) {
    file { $jira::installdir:
      ensure => 'directory',
      owner  => $jira::user,
      group  => $jira::group,
    }
  }

  $file    = "atlassian-${jira::product}-${jira::version}.${jira::format}"
  $ftarget = "${jira::installdir}/atlassian-${jira::product}-${jira::version}-standalone"
  if $jira::staging_or_deploy == 'staging' {

    require staging
    $cleanup_file = "${staging::path}/${caller_module_name}/${file}"

    if ! defined(File[$jira::webappdir]) {
      file { $jira::webappdir:
        ensure => 'directory',
        owner  => $jira::user,
        group  => $jira::group,
      }
    }
    staging::file { $file:
      source  => "${jira::downloadURL}/${file}",
      timeout => 1800,
    } ->
    staging::extract { $file:
      target  => $ftarget,
      creates => "${ftarget}/conf",
      strip   => 1,
      user    => $jira::user,
      group   => $jira::group,
      notify  => Exec["chown_${jira::webappdir}"],
      before  => File[$jira::homedir],
      require => [
        File[$jira::installdir],
        User[$jira::user],
        File[$jira::webappdir] ],
    } ~>
    # Remove the downloaded files after they have been uncompressed.
    exec { "staging-cleanup_${file}":
      command     => "rm -f ${cleanup_file}",
      onlyif      => "test -f ${cleanup_file}",
      refreshonly => true,
      path        => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    }
  } elsif $jira::staging_or_deploy == 'deploy' {
    deploy::file { "atlassian-${jira::product}-${jira::version}.${jira::format}":
      target          => $ftarget,
      url             => $jira::downloadURL,
      strip           => true,
      download_timout => 1800,
      owner           => $jira::user,
      group           => $jira::group,
      notify          => Exec["chown_${jira::webappdir}"],
      before          => File[$jira::homedir],
      require         => [ File[$jira::installdir], User[$jira::user] ],
    }
  } else {
    fail('staging_or_deploy must equal "staging" or "deploy"')
  }

  file { $jira::homedir:
    ensure => 'directory',
    owner  => $jira::user,
    group  => $jira::group,
  } ->

  exec { "chown_${jira::webappdir}":
    command     => "/bin/chown -R ${jira::user}:${jira::group} ${jira::webappdir}",
    refreshonly => true,
    subscribe   => User[$jira::user]
  } ->

  file { '/etc/init.d/jira':
    content => template('jira/etc/rc.d/init.d/jira.erb'),
    mode    => '0755',
  }

}
